@@ -44,7 +44,12 @@ class InspectionMixin:
             else:
                 cc_type = "columns"
 
-            ic = (cc_type, cls.get_column_key(c), cls.get_column_info(c), c)
+            ic = (
+                cc_type,
+                cls.get_column_key(c),
+                cls.get_column_info(c),
+                getattr(cls, k),
+            )
             res[cc_type].append(ic)
             res["all"].append(ic)
             res["all_by_key"][ic[1]] = ic
